@@ -31,7 +31,7 @@ binomCI <- function(x, n, a = 0.05) {
     mod[4, ] <- res
     ## Agresti and Coull
     theta <- (x + 2) / (n + 4)
-    com <- z * sqrt( theta * (1 - theta)/(n + 4) )
+    com <- qnorm(0.975) * sqrt( theta * (1 - theta)/(n + 4) )
     mod[5, ] <- c(theta - com, theta + com)
     ## Wilson
     xb <- x + z^2/2
