@@ -42,7 +42,7 @@ binomCIs <- function(x, n, a = 0.05) {
   colnames(mod[[ 5 ]]) <- c(paste(a/2, "%", sep = ""), paste(1 - a/2, "%", sep = ""))
   ## Agresti and Coull
   theta <- (x + 2) / (n + 4)
-  com <- z * sqrt( theta * (1 - theta)/(n + 4) )
+  com <- qnorm(0.975) * sqrt( theta * (1 - theta)/(n + 4) )
   res <- cbind(theta - com, theta + com)
   mod[[ 6 ]] <- res
   colnames(mod[[ 6 ]]) <- c(paste(a/2, "%", sep = ""), paste(1 - a/2, "%", sep = ""))
